import { BrowserModule } from '@angular/platform-browser';
import { NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { FooterComponent } from './components/footer/footer.component';
import { HeaderComponent } from './components/header/header.component';
import { MoviesComponent } from './routes/movies/movies.component';
import { SeriesComponent } from './routes/series/series.component';
import { ContentComponent } from './routes/content/content.component';
import { LoaderComponent } from './components/loader/loader.component';
import { ErrorComponent } from './components/error/error.component';
import { VideoComponent } from './components/video/video.component';

import { HttpClientInMemoryWebApiModule } from 'angular-in-memory-web-api';
import { InMemoryDataService } from './in-memory-data-service';
import { HttpClientModule, HTTP_INTERCEPTORS }    from '@angular/common/http';
import { LoadingInterceptor } from './services/loading.interceptor';

@NgModule({
  declarations: [
    AppComponent,
    FooterComponent,
    HeaderComponent,
    MoviesComponent,
    SeriesComponent,
    ContentComponent,
    LoaderComponent,
    ErrorComponent,
	VideoComponent
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
	HttpClientModule,
	
	// The HttpClientInMemoryWebApiModule module intercepts HTTP requests
    // and returns simulated server responses.
    // Remove it when a real server is ready to receive requests.
    HttpClientInMemoryWebApiModule.forRoot(
		InMemoryDataService, { dataEncapsulation: false }
	)
  ],
  schemas: [ CUSTOM_ELEMENTS_SCHEMA ],
  providers: [
	{
		provide: HTTP_INTERCEPTORS,
		useClass: LoadingInterceptor,
		multi: true
	  }
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }
